@@ -84,6 +84,47 @@ JNIEXPORT void JNICALL Java_org_tigris_subversion_javahl_SVNClient_finalize
     }
 }
 
+/*
+ * Class:     org_tigris_subversion_javahl_SVNClient
+ * Method:    getAdminDirectoryName
+ * Signature: ()Ljava/lang/String;
+ */
+JNIEXPORT jstring JNICALL Java_org_tigris_subversion_javahl_SVNClient_getAdminDirectoryName
+  (JNIEnv* env, jobject jthis)
+{
+    JNIEntry(SVNClient, getAdminDirectoryName);
+    SVNClient *cl = SVNClient::getCppObject(jthis);
+    if (cl == NULL)
+    {
+        JNIUtil::throwError(_("bad c++ this"));
+        return NULL;
+    }
+    return cl->getAdminDirectoryName();
+}
+
+/*
+ * Class:     org_tigris_subversion_javahl_SVNClient
+ * Method:    isAdminDirectory
+ * Signature: (Ljava/lang/String;)Z
+ */
+JNIEXPORT jboolean JNICALL Java_org_tigris_subversion_javahl_SVNClient_isAdminDirectory
+  (JNIEnv* env, jobject jthis, jstring jname)
+{
+    JNIEntry(SVNClient, isAdminDirectory);
+    SVNClient *cl = SVNClient::getCppObject(jthis);
+    if (cl == NULL)
+    {
+        JNIUtil::throwError(_("bad c++ this"));
+        return JNI_FALSE;
+    }
+    JNIStringHolder name(jname);
+    if (JNIUtil::isExceptionThrown())
+    {
+        return JNI_FALSE;
+    }
+    return cl->isAdminDirectory(name);
+}
+
 /*
  * Class:     org_tigris_subversion_javahl_SVNClient
  * Method:    getLastPath
@@ -92,7 +133,7 @@ JNIEXPORT void JNICALL Java_org_tigris_subversion_javahl_SVNClient_finalize
 JNIEXPORT jstring JNICALL Java_org_tigris_subversion_javahl_SVNClient_getLastPath
   (JNIEnv* env, jobject jthis)
 {
-    JNIEntry(Client, getLastPath);
+    JNIEntry(SVNClient, getLastPath);
     SVNClient *cl = SVNClient::getCppObject(jthis);
     if(cl == NULL)
     {
@@ -200,6 +241,12 @@ JNIEXPORT void JNICALL Java_org_tigris_subversion_javahl_SVNClient_username
         JNIUtil::throwError(_("bad c++ this"));
         return;
     }
+    if (jusername == NULL)
+    {
+        JNIUtil::raiseThrowable("java/lang/IllegalArgumentException",
+                       _("Provide a username (null is not supported)"));
+        return;
+    }
     JNIStringHolder username(jusername);
     if(JNIUtil::isExceptionThrown())
     {
@@ -223,6 +270,12 @@ JNIEXPORT void JNICALL Java_org_tigris_subversion_javahl_SVNClient_password
         JNIUtil::throwError(_("bad c++ this"));
         return;
     }
+    if (jpassword == NULL)
+    {
+        JNIUtil::raiseThrowable("java/lang/IllegalArgumentException",
+		       _("Provide a password (null is not supported)"));
+        return;
+    }
     JNIStringHolder password(jpassword);
     if(JNIUtil::isExceptionThrown())
     {
@@ -1373,6 +1426,36 @@ JNIEXPORT jbyteArray JNICALL Java_org_tigris_subversion_javahl_SVNClient_fileCon
     }
     return cl->fileContent(path, revision, pegRevision);
 }
+
+JNIEXPORT void JNICALL Java_org_tigris_subversion_javahl_SVNClient_streamFileContent
+  (JNIEnv *env, jobject jthis, jstring jpath, jobject jrevision,
+   jobject jpegRevision, jint bufSize, jobject jstream)
+{
+    JNIEntry(SVNClient, streamFileContent);
+    SVNClient *cl = SVNClient::getCppObject(jthis);
+    if (cl == NULL)
+    {
+        JNIUtil::throwError(_("bad c++ this"));
+        return;
+    }
+    JNIStringHolder path(jpath);
+    if (JNIUtil::isExceptionThrown())
+    {
+        return;
+    }
+    Revision revision(jrevision);
+    if (JNIUtil::isExceptionThrown())
+    {
+        return;
+    }
+    Revision pegRevision(jpegRevision);
+    if (JNIUtil::isExceptionThrown())
+    {
+        return;
+    }
+    cl->streamFileContent(path, revision, pegRevision, jstream, bufSize);
+}
+
 /*
  * Class:     org_tigris_subversion_javahl_SVNClient
  * Method:    getVersionInfo
@@ -1732,7 +1815,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_tigris_subversion_javahl_SVNClient_info2
   (JNIEnv *env, jobject jthis, jstring jpath, jobject jrevision, 
    jobject jpegRevision, jboolean jrecurse)
 {
-    JNIEntry(SVNClient, unlock);
+    JNIEntry(SVNClient, info2);
     SVNClient *cl = SVNClient::getCppObject(jthis);
     if(cl == NULL)
     {
@@ -1756,3 +1839,14 @@ JNIEXPORT jobjectArray JNICALL Java_org_tigris_subversion_javahl_SVNClient_info2
     }
     return cl->info2(path, revision, pegRevision, jrecurse ? true : false);
 }
+/*
+ * Class:     org_tigris_subversion_javahl_SVNClient
+ * Method:    initNative
+ * Signature: ()V
+ */
+JNIEXPORT void JNICALL Java_org_tigris_subversion_javahl_SVNClient_initNative
+  (JNIEnv *env, jclass jclazz)
+{
+	// No standard JNIEntry here, because this call initializes everthing
+	JNIUtil::JNIGlobalInit(env);
+}
