@@ -198,6 +198,10 @@ typedef struct
   const char *base_dir;
   svn_wc_adm_access_t *base_access;
 
+  /* When true, makes sure temporary files are created
+     outside the working copy. */
+  svn_boolean_t read_only_wc;
+
   /* An array of svn_client_commit_item2_t * structures, present only
      during working copy commits. */
   apr_array_header_t *commit_items;
@@ -313,6 +317,12 @@ svn_error_t * svn_client__wc_delete(const char *path,
                                     svn_client_ctx_t *ctx,
                                     apr_pool_t *pool);
 
+/* Return the list of WC paths to entries which would have been
+   deleted by an update/merge if not in "dry run" mode, or NULL if not
+   in "dry run" mode.  MERGE_CMD_BATON contains the list, which is
+   intended for direct modification. */
+apr_hash_t *svn_client__dry_run_deletions(void *merge_cmd_baton);
+
 /* ---------------------------------------------------------------- */
 
 /*** Checkout, update and switch ***/
@@ -429,7 +439,9 @@ svn_client__get_diff_editor(const char *target,
  * repository version against the other and only providing information
  * about the changed items without the text deltas.
  *
- * @a summarize_func is called with @a summarize_baton as parameter by the
+ * TARGET is the target of the diff, relative to the root of the edit.
+ *
+ * SUMMARIZE_FUNC is called with SUMMARIZE_BATON as parameter by the
  * created svn_delta_editor_t for each changed item.
  *
  * See svn_client__get_diff_editor() for a description of the other
