@@ -24,6 +24,7 @@
 #include <ne_socket.h>
 #include <ne_uri.h>
 #include <ne_compress.h>
+#include <ne_basic.h>
 
 #include "svn_pools.h"
 #include "svn_path.h"
@@ -284,17 +285,17 @@ svn_error_t *svn_ra_dav__convert_error(ne_session *sess,
 
     default:
       /* Get the error string from neon and convert to UTF-8. */
-      SVN_ERR (svn_utf_cstring_to_utf8 (&msg, ne_get_error (sess), pool));
+      SVN_ERR(svn_utf_cstring_to_utf8(&msg, ne_get_error(sess), pool));
       break;
     }
 
   /* The hostname may contain non-ASCII characters, so convert it to UTF-8. */
-  SVN_ERR (svn_utf_cstring_to_utf8 (&hostport, ne_get_server_hostport(sess),
-                                    pool));
+  SVN_ERR(svn_utf_cstring_to_utf8(&hostport, ne_get_server_hostport(sess),
+                                  pool));
 
-  return svn_error_createf (errcode, NULL, "%s: %s (%s://%s)", 
-                            context, msg, ne_get_scheme(sess), 
-                            hostport);
+  return svn_error_createf(errcode, NULL, "%s: %s (%s://%s)", 
+                           context, msg, ne_get_scheme(sess), 
+                           hostport);
 }
 
 
@@ -306,8 +307,28 @@ static int ra_dav_error_accepter(void *userdata,
                                  ne_request *req,
                                  const ne_status *st)
 {
+  /* Before, this function was being run for *all* responses including
+     the 401 auth challenge.  In neon 0.24.x that was harmless.  But
+     in neon 0.25.0, trying to parse a 401 response as XML using
+     ne_xml_parse_v aborts the response; so the auth hooks never got a
+     chance. */
+#ifdef SVN_NEON_0_25
+  ne_content_type ctype;
+
+  /* Only accept non-2xx responses with text/xml content-type */
+  if (st->klass != 2 && ne_get_content_type(req, &ctype) == 0)
+    {
+      int is_xml = 
+        (strcmp(ctype.type, "text") == 0 && strcmp(ctype.subtype, "xml") == 0);
+      ne_free(ctype.value);        
+      return is_xml;
+    }
+  else 
+    return 0;
+#else /* ! SVN_NEON_0_25 */
   /* Only accept the body-response if the HTTP status code is *not* 2XX. */
   return (st->klass != 2);
+#endif /* if/else SVN_NEON_0_25 */
 }
 
 
@@ -428,9 +449,9 @@ static int end_err_element(void *userdata, const svn_ra_dav__xml_elm_t *elm,
  * from an APR file. See ne_request.h for a description of the
  * interface.
  */
-static ssize_t ra_dav_body_provider (void *userdata,
-                                     char *buffer,
-                                     size_t buflen)
+static ssize_t ra_dav_body_provider(void *userdata,
+                                    char *buffer,
+                                    size_t buflen)
 {
   apr_file_t *body_file = userdata;
   apr_status_t status;
@@ -483,7 +504,12 @@ typedef struct spool_reader_baton_t
 } spool_reader_baton_t;
 
 
-static void 
+/* This implements the ne_block_reader() callback interface. */
+#ifdef SVN_NEON_0_25
+static int
+#else /* ! SVN_NEON_0_25 */
+static void
+#endif /* if/else SVN_NEON_0_25 */
 spool_reader(void *userdata, 
              const char *buf, 
              size_t len)
@@ -492,6 +518,14 @@ spool_reader(void *userdata,
   if (! baton->error)
     baton->error = svn_io_file_write_full(baton->spool_file, buf, 
                                           len, NULL, baton->pool);
+
+#ifdef SVN_NEON_0_25
+  if (baton->error)
+    /* ### Call ne_set_error(), as ne_block_reader doc implies? */
+    return 1;
+  else
+    return 0;
+#endif /* SVN_NEON_0_25 */
 }
 
 
@@ -502,19 +536,19 @@ parse_spool_file(const char *spool_file_name,
 {
   apr_file_t *spool_file;
   svn_stream_t *spool_stream;
-  char *buf = apr_palloc(pool, SVN_STREAM_CHUNK_SIZE);
+  char *buf = apr_palloc(pool, SVN__STREAM_CHUNK_SIZE);
   apr_size_t len;
   
-  SVN_ERR( svn_io_file_open(&spool_file, spool_file_name,
-                            (APR_READ | APR_BUFFERED), APR_OS_DEFAULT, pool));
+  SVN_ERR(svn_io_file_open(&spool_file, spool_file_name,
+                           (APR_READ | APR_BUFFERED), APR_OS_DEFAULT, pool));
   spool_stream = svn_stream_from_aprfile(spool_file, pool);
   while (1)
     {
-      len = SVN_STREAM_CHUNK_SIZE;
-      SVN_ERR (svn_stream_read (spool_stream, buf, &len));
+      len = SVN__STREAM_CHUNK_SIZE;
+      SVN_ERR(svn_stream_read(spool_stream, buf, &len));
       if (len > 0)
         ne_xml_parse(success_parser, buf, len);
-      if (len != SVN_STREAM_CHUNK_SIZE)
+      if (len != SVN__STREAM_CHUNK_SIZE)
         break;
     }
   return SVN_NO_ERROR;
@@ -532,8 +566,8 @@ parsed_request(ne_session *sess,
                const char *url,
                const char *body,
                apr_file_t *body_file,
-               void set_parser (ne_xml_parser *parser,
-                                void *baton),
+               void set_parser(ne_xml_parser *parser,
+                               void *baton),
                const svn_ra_dav__xml_elm_t *elements,
                svn_boolean_t use_neon_shim,
                /* These three are defined iff use_neon_shim is defined. */
@@ -556,7 +590,9 @@ parsed_request(ne_session *sess,
   ne_xml_parser *success_parser = NULL;
   ne_xml_parser *error_parser = NULL;
   int rv;
+#ifndef SVN_NEON_0_25
   int decompress_rv;
+#endif /* ! SVN_NEON_0_25 */
   int code;
   int expected_code;
   const char *msg;
@@ -580,12 +616,12 @@ parsed_request(ne_session *sess,
   if (extra_headers != NULL)
     {
       apr_hash_index_t *hi;
-      for (hi = apr_hash_first (pool, extra_headers);
-           hi; hi = apr_hash_next (hi))
+      for (hi = apr_hash_first(pool, extra_headers);
+           hi; hi = apr_hash_next(hi))
         {
           const void *key;
           void *val;
-          apr_hash_this (hi, &key, NULL, &val);
+          apr_hash_this(hi, &key, NULL, &val);
           ne_add_request_header(req, (const char *) key, (const char *) val); 
         }
     }
@@ -639,9 +675,12 @@ parsed_request(ne_session *sess,
         goto cleanup;
 
       tmpfile_path = svn_path_join(tmpfile_path, "dav-spool", pool);
-      SVN_ERR (svn_io_open_unique_file (&spool_reader_baton.spool_file, 
-                                        &spool_reader_baton.spool_file_name,
-                                        tmpfile_path, "", FALSE, pool));
+      err = svn_io_open_unique_file2(&spool_reader_baton.spool_file,
+                                     &spool_reader_baton.spool_file_name,
+                                     tmpfile_path, "",
+                                     svn_io_file_del_none, pool);
+      if (err)
+        goto cleanup;
       spool_reader_baton.pool = pool;
       spool_reader_baton.error = SVN_NO_ERROR;
       if (ras->compression)
@@ -689,6 +728,13 @@ parsed_request(ne_session *sess,
         }
     }
 
+#ifdef SVN_NEON_0_25
+  if (decompress_main)
+    ne_decompress_destroy(decompress_main);
+
+  if (decompress_err)
+    ne_decompress_destroy(decompress_err);
+#else  /* ! SVN_NEON_0_25 */
   if (decompress_main)
     {
       decompress_rv = ne_decompress_destroy(decompress_main);
@@ -706,6 +752,7 @@ parsed_request(ne_session *sess,
           rv = decompress_rv;
         }
     }
+#endif /* if/else SVN_NEON_0_25 */
   
   code = ne_get_status(req)->code;
   if (status_code)
@@ -789,8 +836,8 @@ svn_ra_dav__parsed_request(ne_session *sess,
                            const char *url,
                            const char *body,
                            apr_file_t *body_file,
-                           void set_parser (ne_xml_parser *parser,
-                                            void *baton),
+                           void set_parser(ne_xml_parser *parser,
+                                           void *baton),
                            ne_xml_startelm_cb *startelm_cb,
                            ne_xml_cdata_cb *cdata_cb,
                            ne_xml_endelm_cb *endelm_cb,
@@ -814,8 +861,8 @@ svn_ra_dav__parsed_request_compat(ne_session *sess,
                                   const char *url,
                                   const char *body,
                                   apr_file_t *body_file,
-                                  void set_parser (ne_xml_parser *parser,
-                                                   void *baton),
+                                  void set_parser(ne_xml_parser *parser,
+                                                  void *baton),
                                   const svn_ra_dav__xml_elm_t *elements, 
                                   svn_ra_dav__xml_validate_cb validate_cb,
                                   svn_ra_dav__xml_startelm_cb startelm_cb, 
@@ -836,15 +883,16 @@ svn_ra_dav__parsed_request_compat(ne_session *sess,
 
 
 svn_error_t *
-svn_ra_dav__maybe_store_auth_info(svn_ra_dav__session_t *ras)
+svn_ra_dav__maybe_store_auth_info(svn_ra_dav__session_t *ras,
+                                  apr_pool_t *pool)
 {
   /* No auth_baton?  Never mind. */
   if (! ras->callbacks->auth_baton)
     return SVN_NO_ERROR;
 
   /* If we ever got credentials, ask the iter_baton to save them.  */
-  SVN_ERR (svn_auth_save_credentials(ras->auth_iterstate,
-                                     ras->pool));
+  SVN_ERR(svn_auth_save_credentials(ras->auth_iterstate,
+                                    pool));
   
   return SVN_NO_ERROR;
 }
@@ -852,11 +900,12 @@ svn_ra_dav__maybe_store_auth_info(svn_ra_dav__session_t *ras)
 
 svn_error_t *
 svn_ra_dav__maybe_store_auth_info_after_result(svn_error_t *err,
-                                               svn_ra_dav__session_t *ras)
+                                               svn_ra_dav__session_t *ras,
+                                               apr_pool_t *pool)
 {
   if (! err || (err->apr_err != SVN_ERR_RA_NOT_AUTHORIZED))
     {
-      svn_error_t *err2 = svn_ra_dav__maybe_store_auth_info(ras);
+      svn_error_t *err2 = svn_ra_dav__maybe_store_auth_info(ras, pool);
       if (err2 && ! err)
         return err2;
       else if (err)
@@ -900,6 +949,10 @@ svn_ra_dav__request_dispatch(int *code_p,
                              const char *url,
                              int okay_1,
                              int okay_2,
+#ifdef SVN_NEON_0_25
+                             svn_ra_dav__request_interrogator interrogator,
+                             void *interrogator_baton,
+#endif /* SVN_NEON_0_25 */
                              apr_pool_t *pool)
 {
   ne_xml_parser *error_parser;
@@ -909,6 +962,9 @@ svn_ra_dav__request_dispatch(int *code_p,
   int code;
   const char *msg;
   svn_error_t *err = SVN_NO_ERROR;
+#ifdef SVN_NEON_0_25
+  svn_error_t *err2 = SVN_NO_ERROR;
+#endif /* SVN_NEON_0_25 */
 
   /* attach a standard <D:error> body parser to the request */
   error_parser = ne_xml_create();
@@ -927,9 +983,23 @@ svn_ra_dav__request_dispatch(int *code_p,
   if (code_p)
      *code_p = code;
 
+#ifdef SVN_NEON_0_25
+  if (interrogator)
+    err2 = (*interrogator)(request, rv, interrogator_baton);
+#endif /* SVN_NEON_0_25 */
+
   ne_request_destroy(request);
   ne_xml_destroy(error_parser);
 
+#ifdef SVN_NEON_0_25
+  /* If the request interrogator returned error, pass that along now. */
+  if (err2)
+    {
+      svn_error_clear(err);
+      return err2;
+    }
+#endif /* SVN_NEON_0_25 */
+
   /* If the status code was one of the two that we expected, then go
      ahead and return now. IGNORE any marshalled error. */
   if (rv == NE_OK && (code == okay_1 || code == okay_2))
