@@ -2,7 +2,7 @@
  * opt.c :  option and argument parsing for Subversion command lines
  *
  * ====================================================================
- * Copyright (c) 2000-2006 CollabNet.  All rights reserved.
+ * Copyright (c) 2000-2007 CollabNet.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -730,9 +730,29 @@ svn_opt_parse_path(svn_opt_revision_t *rev,
             }
           else  /* looking at non-empty peg revision */
             {
+              const char *rev_str = path + i + 1;
+
+              if (is_url)
+                {
+                  /* URLs are URI-encoded, so we look for dates with
+                     URI-encoded delimeters.  */
+                  int rev_len = strlen(rev_str);
+                  if (rev_len > 6
+                      && rev_str[0] == '%' 
+                      && rev_str[1] == '7' 
+                      && (rev_str[2] == 'B' 
+                          || rev_str[2] == 'b')
+                      && rev_str[rev_len-3] == '%' 
+                      && rev_str[rev_len-2] == '7' 
+                      && (rev_str[rev_len-1] == 'D' 
+                          || rev_str[rev_len-1] == 'd'))
+                    {
+                      rev_str = svn_path_uri_decode(rev_str, pool);
+                    }
+                }
               ret = svn_opt_parse_revision(&start_revision,
                                            &end_revision,
-                                           path + i + 1, pool);
+                                           rev_str, pool);
             }
 
           if (ret || end_revision.kind != svn_opt_revision_unspecified)
@@ -954,7 +974,7 @@ print_version_info(const char *pgm_name,
   SVN_ERR(svn_cmdline_printf(pool, _("%s, version %s\n"
                                      "   compiled %s, %s\n\n"), pgm_name,
                              SVN_VERSION, __DATE__, __TIME__));
-  SVN_ERR(svn_cmdline_fputs(_("Copyright (C) 2000-2006 CollabNet.\n"
+  SVN_ERR(svn_cmdline_fputs(_("Copyright (C) 2000-2007 CollabNet.\n"
                               "Subversion is open source software, see"
                               " http://subversion.tigris.org/\n"
                               "This product includes software developed by "
