@@ -178,18 +178,10 @@ remove_revert_file(svn_stringbuf_t **logtags,
                    apr_pool_t * pool)
 {
   const char * revert_file;
-  const svn_wc_entry_t *entry;
   svn_node_kind_t kind;
 
-  SVN_ERR(svn_wc_entry(&entry, base_name, adm_access, FALSE, pool));
-
-  /*### Maybe assert (entry); calling remove_revert_file
-    for an unversioned file is bogus */
-  if (! entry)
-    return SVN_NO_ERROR;
-
   if (is_prop)
-    SVN_ERR(svn_wc__prop_revert_path(&revert_file, base_name, entry->kind,
+    SVN_ERR(svn_wc__prop_revert_path(&revert_file, base_name, svn_node_file,
                                      FALSE, pool));
   else
     revert_file = svn_wc__text_revert_path(base_name, FALSE, pool);
@@ -309,25 +301,24 @@ svn_wc_maybe_set_repos_root(svn_wc_adm_access_t *adm_access,
 }
 
 
-svn_error_t *
-svn_wc_process_committed3(const char *path,
-                          svn_wc_adm_access_t *adm_access,
-                          svn_boolean_t recurse,
-                          svn_revnum_t new_revnum,
-                          const char *rev_date,
-                          const char *rev_author,
-                          apr_array_header_t *wcprop_changes,
-                          svn_boolean_t remove_lock,
-                          const unsigned char *digest,
-                          apr_pool_t *pool)
+static svn_error_t *
+process_committed_leaf(int log_number,
+                       const char *path,
+                       svn_wc_adm_access_t *adm_access,
+                       svn_boolean_t *recurse,
+                       svn_revnum_t new_revnum,
+                       const char *rev_date,
+                       const char *rev_author,
+                       apr_array_header_t *wcprop_changes,
+                       svn_boolean_t remove_lock,
+                       const unsigned char *digest,
+                       apr_pool_t *pool)
 {
   const char *base_name;
-  svn_stringbuf_t *logtags;
   const char *hex_digest = NULL;
   svn_wc_entry_t tmp_entry;
   apr_uint32_t modify_flags = 0;
-
-  logtags = svn_stringbuf_create("", pool);
+  svn_stringbuf_t *logtags = svn_stringbuf_create("", pool);
 
   SVN_ERR(svn_wc__adm_write_check(adm_access));
 
@@ -386,7 +377,8 @@ svn_wc_process_committed3(const char *path,
         }
 
       /* Oh, and recursing at this point isn't really sensible. */
-      recurse = FALSE;
+      if (recurse)
+        *recurse = FALSE;
     }
   else
     {
@@ -457,10 +449,30 @@ svn_wc_process_committed3(const char *path,
     }
 
   /* Write our accumulation of log entries into a log file */
-  SVN_ERR(svn_wc__write_log(adm_access, 0, logtags, pool));
+  SVN_ERR(svn_wc__write_log(adm_access, log_number, logtags, pool));
 
-  /* Run the log file we just created. */
-  SVN_ERR(svn_wc__run_log(adm_access, NULL, pool));
+  return SVN_NO_ERROR;
+}
+
+
+svn_error_t *
+svn_wc_process_committed3(const char *path,
+                          svn_wc_adm_access_t *adm_access,
+                          svn_boolean_t recurse,
+                          svn_revnum_t new_revnum,
+                          const char *rev_date,
+                          const char *rev_author,
+                          apr_array_header_t *wcprop_changes,
+                          svn_boolean_t remove_lock,
+                          const unsigned char *digest,
+                          apr_pool_t *pool)
+{
+  int log_number = 1;
+
+  SVN_ERR(process_committed_leaf(0, path, adm_access, &recurse,
+                                 new_revnum, rev_date, rev_author,
+                                 wcprop_changes,
+                                 remove_lock, digest, pool));
 
   if (recurse)
     {
@@ -504,15 +516,39 @@ svn_wc_process_committed3(const char *path,
              a directory.  Pass null for wcprop_changes, because the
              ones present in the current call are only applicable to
              this one committed item. */
-          SVN_ERR(svn_wc_process_committed2
-                  (this_path, child_access,
-                   (current_entry->kind == svn_node_dir) ? TRUE : FALSE,
-                   new_revnum, rev_date, rev_author, NULL, FALSE, subpool));
+          if (current_entry->kind == svn_node_dir)
+            SVN_ERR(svn_wc_process_committed2
+                    (this_path, child_access,
+                     (current_entry->kind == svn_node_dir) ? TRUE : FALSE,
+                     new_revnum, rev_date, rev_author, NULL, FALSE, subpool));
+          else
+            {
+              /* No log file is executed at this time. In case this folder
+                 gets replaced, the entries file might still contain files 
+                 scheduled for deletion. No need to process those here, they
+                 will be when the parent is processed. */
+              if (current_entry->schedule == svn_wc_schedule_delete)
+                {
+                  svn_wc_entry_t *parent_entry;
+
+                  parent_entry = apr_hash_get(entries, SVN_WC_ENTRY_THIS_DIR, 
+                                              APR_HASH_KEY_STRING);
+                  if (parent_entry->schedule == svn_wc_schedule_replace)
+                    continue;
+                }
+              SVN_ERR(process_committed_leaf
+                      (log_number++, this_path, adm_access, NULL,
+                       new_revnum, rev_date, rev_author, FALSE, FALSE,
+                       NULL, subpool));
+          }
         }
 
       svn_pool_destroy(subpool); 
    }
 
+  /* Run the log file(s) we just created. */
+  SVN_ERR(svn_wc__run_log(adm_access, NULL, pool));
+
   return SVN_NO_ERROR;
 }
 
@@ -1150,12 +1186,17 @@ svn_wc_add2(const char *path,
       modify_flags |= SVN_WC__ENTRY_MODIFY_COPIED;
     }
 
-  /* If this is a replacement we want to remove the checksum so it is not set
-   * to the old value. */
+  /* If this is a replacement we want to remove the checksum and the property
+     flags so they are not set to their respective old values. */
   if (is_replace)
     {
       tmp_entry.checksum = NULL;
       modify_flags |= SVN_WC__ENTRY_MODIFY_CHECKSUM;
+
+      tmp_entry.has_props = FALSE;
+      tmp_entry.has_prop_mods = FALSE;
+      modify_flags |= SVN_WC__ENTRY_MODIFY_HAS_PROPS;
+      modify_flags |= SVN_WC__ENTRY_MODIFY_HAS_PROP_MODS;
     }
   
   tmp_entry.revision = 0;
@@ -1372,6 +1413,7 @@ revert_admin_things(svn_wc_adm_access_t *adm_access,
   svn_stringbuf_t *log_accum = svn_stringbuf_create("", pool);
   apr_hash_t *baseprops = NULL;
   const char *adm_path = svn_wc_adm_access_path(adm_access);
+  svn_boolean_t revert_base = FALSE;
 
   /* Build the full path of the thing we're reverting. */
   fullpath = svn_wc_adm_access_path(adm_access);
@@ -1379,24 +1421,34 @@ revert_admin_things(svn_wc_adm_access_t *adm_access,
     fullpath = svn_path_join(fullpath, name, pool);
 
   /* Deal with properties. */
-
   if (entry->schedule == svn_wc_schedule_replace)
     {
       const char *rprop;
       svn_node_kind_t kind;
 
+      revert_base = TRUE;
       /* Use the revertpath as the new propsbase if it exists. */
       SVN_ERR(svn_wc__prop_revert_path(&rprop, fullpath, entry->kind, FALSE,
                                        pool));
       SVN_ERR(svn_io_check_path(rprop, &kind, pool));
+
+      /* If the revert-base doesn't exist, check for a normal propsbase */
+      if (kind != svn_node_file)
+        {
+          SVN_ERR(svn_wc__prop_base_path(&rprop, fullpath, entry->kind, FALSE,
+                                         pool));
+          SVN_ERR(svn_io_check_path(rprop, &kind, pool));
+          revert_base = FALSE;
+        }
       if (kind == svn_node_file)
         {
           baseprops = apr_hash_make(pool);
           SVN_ERR(svn_wc__load_prop_file(rprop, baseprops, pool));
           /* Ensure the revert propfile gets removed. */
-          SVN_ERR(svn_wc__loggy_remove
-                  (&log_accum, adm_access,
-                   svn_path_is_child(adm_path, rprop, pool), pool));
+          if (revert_base)
+            SVN_ERR(svn_wc__loggy_remove
+                    (&log_accum, adm_access,
+                     svn_path_is_child(adm_path, rprop, pool), pool));
           *reverted = TRUE;
         }
     }
@@ -1429,10 +1481,13 @@ revert_admin_things(svn_wc_adm_access_t *adm_access,
   /* Reinstall props if we need to.  Only rewrite the baseprops,
      if we're reverting a replacement.  This is just an optimization. */
   if (baseprops)
-    SVN_ERR(svn_wc__install_props(&log_accum, adm_access, name, baseprops,
-                                  baseprops,
-                                  entry->schedule == svn_wc_schedule_replace,
-                                  pool));
+    {
+      SVN_ERR(svn_wc__install_props(&log_accum, adm_access, name, baseprops,
+                                    baseprops,
+                                    revert_base,
+                                    pool));
+      *reverted = TRUE;
+    }
 
   /* Clean up the copied state if this is a replacement. */
   if (entry->schedule == svn_wc_schedule_replace
@@ -1745,19 +1800,42 @@ svn_wc_revert2(const char *path,
            || entry->schedule == svn_wc_schedule_replace)
     {
       /* Revert the prop and text mods (if any). */
-      if (entry->kind == svn_node_file)
-        SVN_ERR(revert_admin_things(parent_access, bname,
-                                    entry, &reverted,
-                                    use_commit_times, pool));
+      switch (entry->kind)
+        {
+        case svn_node_file:
+          SVN_ERR(revert_admin_things(parent_access, bname, entry,
+                                      &reverted, use_commit_times, pool));
+          break;
 
-      if (entry->kind == svn_node_dir)
-        SVN_ERR(revert_admin_things(dir_access, SVN_WC_ENTRY_THIS_DIR, entry,
-                                    &reverted, use_commit_times, pool));
+        case svn_node_dir:
+          SVN_ERR(revert_admin_things(dir_access, SVN_WC_ENTRY_THIS_DIR, entry,
+                                      &reverted, use_commit_times, pool));
 
-      /* Force recursion on replaced directories. */
-      if ((entry->kind == svn_node_dir)
-          && (entry->schedule == svn_wc_schedule_replace))
-        recursive = TRUE;
+          /* Also revert the entry in the parent (issue #2804). */
+          if (reverted && bname)
+            {
+              svn_boolean_t dummy_reverted;
+              svn_wc_entry_t *entry_in_parent;
+              apr_hash_t *entries;
+
+              SVN_ERR(svn_wc_entries_read(&entries, parent_access, TRUE,
+                                          pool));
+              entry_in_parent = apr_hash_get(entries, bname,
+                                             APR_HASH_KEY_STRING);
+              SVN_ERR(revert_admin_things(parent_access, bname,
+                                          entry_in_parent, &dummy_reverted,
+                                          use_commit_times, pool));
+            }
+
+          /* Force recursion on replaced directories. */
+          if (entry->schedule == svn_wc_schedule_replace)
+            recursive = TRUE;
+          break;
+
+        default:
+          /* No op? */
+          break;
+        }
     }
 
   /* If PATH was reverted, tell our client that. */
@@ -1862,16 +1940,26 @@ svn_wc_remove_from_revision_control(svn_wc_adm_access_t *adm_access,
       
   if (is_file)
     {
+      svn_node_kind_t kind;
+      svn_boolean_t wc_special, local_special;
       svn_boolean_t text_modified_p;
       full_path = svn_path_join(full_path, name, pool);
 
-      /* Check for local mods. before removing entry */
-      SVN_ERR(svn_wc_text_modified_p(&text_modified_p, full_path,
-                                     FALSE, adm_access, pool));
-      if (text_modified_p && instant_error)
-        return svn_error_createf(SVN_ERR_WC_LEFT_LOCAL_MOD, NULL,
-                                 _("File '%s' has local modifications"),
-                                 svn_path_local_style(full_path, pool));
+      /* Only check if the file was modified when it wasn't overwritten with a 
+         special file */
+      SVN_ERR(svn_wc__get_special(&wc_special, full_path, adm_access, pool));
+      SVN_ERR(svn_io_check_special_path(full_path, &kind, &local_special, 
+                                        pool));
+      if (wc_special || ! local_special)
+        {
+          /* Check for local mods. before removing entry */
+          SVN_ERR(svn_wc_text_modified_p(&text_modified_p, full_path,
+                  FALSE, adm_access, pool));
+          if (text_modified_p && instant_error)
+            return svn_error_createf(SVN_ERR_WC_LEFT_LOCAL_MOD, NULL,
+                   _("File '%s' has local modifications"),
+                   svn_path_local_style(full_path, pool));
+        }
 
       /* Remove the wcprops. */
       SVN_ERR(svn_wc__remove_wcprops(adm_access, name, FALSE, pool));
@@ -1908,7 +1996,8 @@ svn_wc_remove_from_revision_control(svn_wc_adm_access_t *adm_access,
          it has local mods. */
       if (destroy_wf)
         {
-          if (text_modified_p)  /* Don't kill local mods. */
+          /* Don't kill local mods. */
+          if (text_modified_p || (! wc_special && local_special))
             return svn_error_create(SVN_ERR_WC_LEFT_LOCAL_MOD, NULL, NULL);
           else  /* The working file is still present; remove it. */
             SVN_ERR(remove_file_if_present(full_path, pool));
