@@ -2484,6 +2484,16 @@ def basic_diff_summarize(sbox):
                                         None, None, None, None,
                                         wc_dir)
 
+  # Get the differences between two files.
+  expected_diff = svntest.wc.State(wc_dir, {
+    'iota': Item(status=' M'),
+    })
+  svntest.actions.run_and_verify_diff_summarize(expected_diff, None,
+                                                None, None, None, None,
+                                                os.path.join(wc_dir, 'iota'),
+                                                '-c2')
+
+  # Get the differences between two versions of an entire directory.
   expected_diff = svntest.wc.State(wc_dir, {
     'A/mu': Item(status='M '),
     'iota': Item(status=' M'),
@@ -2626,6 +2636,57 @@ def diff_ignore_eolstyle(sbox):
                                      'diff', '-x', '--ignore-eol-style', 
                                      file_path)
 
+# test for issue 2600, diff revision of a file in a renamed folder
+def diff_in_renamed_folder(sbox):
+  "diff a revision of a file in a renamed folder"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+
+  C_path = os.path.join(wc_dir, "A", "C")
+  D_path = os.path.join(wc_dir, "A", "D")
+  kappa_path = os.path.join(D_path, "C", "kappa")
+
+  # add a new file to a renamed (moved in this case) folder.
+  svntest.main.run_svn(None, 'mv', C_path, D_path)
+
+  svntest.main.file_append(kappa_path, "this is file kappa.\n")
+  svntest.main.run_svn(None, 'add', kappa_path)
+
+  expected_output = svntest.wc.State(wc_dir, {
+      'A/C' : Item(verb='Deleting'),
+      'A/D/C' : Item(verb='Adding'),
+      'A/D/C/kappa' : Item(verb='Adding'),
+  })
+  svntest.actions.run_and_verify_commit(wc_dir, expected_output,
+                                        None, None, None, None,
+                                        None, None, wc_dir)
+
+  expected_output = svntest.wc.State(wc_dir, {
+      'A/D/C/kappa' : Item(verb='Sending'),
+  })
+
+  # modify the file two times so we have something to diff.
+  for i in range(3, 5):
+    svntest.main.file_append(kappa_path, str(i) + "\n")
+    svntest.actions.run_and_verify_commit(wc_dir, expected_output,
+                                          None, None, None, None,
+                                          None, None, wc_dir)  
+
+  expected_output = [
+    "Index: svn-test-work/working_copies/diff_tests-41/A/D/C/kappa\n",
+    "===================================================================\n",
+    "--- svn-test-work/working_copies/diff_tests-41/A/D/C/kappa\t(revision 3)\n",
+    "+++ svn-test-work/working_copies/diff_tests-41/A/D/C/kappa\t(revision 4)\n",
+    "@@ -1,2 +1,3 @@\n",
+    " this is file kappa.\n",
+    " 3\n",
+    "+4\n"
+  ]
+
+  svntest.actions.run_and_verify_svn(None, expected_output, [],
+                                     'diff', '-r3:4', kappa_path)
+
 ########################################################################
 #Run the tests
 
@@ -2672,6 +2733,7 @@ test_list = [ None,
               diff_weird_author,
               diff_ignore_whitespace,
               diff_ignore_eolstyle,
+              diff_in_renamed_folder,
               ]
 
 if __name__ == '__main__':
