@@ -354,6 +354,33 @@ def update_conflict_props(sbox):
 
   svntest.actions.run_and_verify_status(wc_dir, expected_status)
 
+#----------------------------------------------------------------------
+def commit_conflict_dirprops(sbox):
+  "commit with conflicting dirprops"
+  
+  # Issue #2608: failure to see conflicting dirprops on root of
+  # repository.
+
+  # Bootstrap
+  sbox.build()
+  wc_dir = sbox.wc_dir
+
+  svntest.main.run_svn(None, 'propset', 'foo', 'bar', wc_dir)
+
+  # Commit the file and directory
+  svntest.main.run_svn(None, 'ci', '-m', 'r2', wc_dir)
+
+  # Update to rev 1
+  svntest.main.run_svn(None, 'up', '-r', '1', wc_dir)
+
+  # Add conflicting properties
+  svntest.main.run_svn(None, 'propset', 'foo', 'eek', wc_dir)
+
+  svntest.actions.run_and_verify_commit(wc_dir, None, None,
+                                        "[Oo]ut[- ]of[- ]date",
+                                        None, None, None, None,
+                                        wc_dir)
+
 #----------------------------------------------------------------------
 
 # Issue #742: we used to screw up when committing a file replacement
@@ -525,6 +552,11 @@ def inappropriate_props(sbox):
                                      'svn:externals',
                                      'foo http://host.com/repos', iota_path)
 
+  svntest.actions.run_and_verify_svn('Invalid svn:eol-style', None,
+                                     svntest.SVNAnyOutput, 'propset',
+                                     'svn:eol-style', 'invalid value',
+                                     os.path.join(A_path, 'mu'))
+
   svntest.actions.run_and_verify_svn('Illegal target', None,
                                      svntest.SVNAnyOutput, 'propset',
                                      'svn:author', 'socrates', iota_path)
@@ -1126,6 +1158,39 @@ def removal_schedule_added_props(sbox):
 
 
 
+# test for issue 2743
+def props_on_replaced_file(sbox):
+  """test properties on replaced files"""
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+
+  # Add some properties to iota
+  iota_path = os.path.join(wc_dir, "iota")
+  svntest.main.run_svn(None, 'propset', 'red', 'rojo', iota_path)
+  svntest.main.run_svn(None, 'propset', 'blue', 'lagoon', iota_path)
+  svntest.main.run_svn(None, 'ci', '-m', 'log message', wc_dir)
+
+  # replace iota_path
+  svntest.main.run_svn(None, 'rm', iota_path)
+  svntest.main.file_append(iota_path, "some mod")
+  svntest.main.run_svn(None, 'add', iota_path)
+
+  # check that the replaced file has no properties
+  expected_disk = svntest.main.greek_state.copy()
+  expected_disk.tweak('iota', contents="some mod")
+  actual_disk_tree = svntest.tree.build_tree_from_wc(wc_dir, 1)
+  svntest.tree.compare_trees(actual_disk_tree, expected_disk.old_tree())
+
+  # now add a new property to iota
+  svntest.main.run_svn(None, 'propset', 'red', 'mojo', iota_path)
+  svntest.main.run_svn(None, 'propset', 'groovy', 'baby', iota_path)
+
+  # What we expect the disk tree to look like:
+  expected_disk.tweak('iota', props={'red' : 'mojo', 'groovy' : 'baby'})
+  actual_disk_tree = svntest.tree.build_tree_from_wc(wc_dir, 1)
+  svntest.tree.compare_trees(actual_disk_tree, expected_disk.old_tree())
+
 ########################################################################
 # Run the tests
 
@@ -1138,6 +1203,7 @@ test_list = [ None,
               downdate_props,
               remove_props,
               update_conflict_props,
+              commit_conflict_dirprops,
               commit_replacement_props,
               revert_replacement_props,
               inappropriate_props,
@@ -1151,6 +1217,7 @@ test_list = [ None,
               recursive_base_wc_ops,
               url_props_ops,
               removal_schedule_added_props,
+              props_on_replaced_file,
              ]
 
 if __name__ == '__main__':
