@@ -583,6 +583,255 @@ def revert_after_manual_conflict_resolution__prop(sbox):
   svntest.actions.run_and_verify_svn(None, [], [], "diff", wc_dir_2)
   svntest.actions.run_and_verify_svn(None, [], [], "revert", "-R", wc_dir_2)
 
+def revert_propset__dir(sbox):
+  "revert a simple propset on a dir"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  a_path = os.path.join(wc_dir, 'A')
+  svntest.main.run_svn(None, 'propset', 'foo', 'x', a_path)
+  expected_output = re.escape("Reverted '" + a_path + "'")
+  svntest.actions.run_and_verify_svn(None, expected_output, [], "revert",
+                                     a_path)
+
+def revert_propset__file(sbox):
+  "revert a simple propset on a file"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  iota_path = os.path.join(wc_dir, 'iota')
+  svntest.main.run_svn(None, 'propset', 'foo', 'x', iota_path)
+  expected_output = re.escape("Reverted '" + iota_path + "'")
+  svntest.actions.run_and_verify_svn(None, expected_output, [], "revert",
+                                     iota_path)
+
+def revert_propdel__dir(sbox):
+  "revert a simple propdel on a dir"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  a_path = os.path.join(wc_dir, 'A')
+  svntest.main.run_svn(None, 'propset', 'foo', 'x', a_path)
+  svntest.main.run_svn(None, 'commit', '-m', 'ps', a_path)
+  svntest.main.run_svn(None, 'propdel', 'foo', a_path)
+  expected_output = re.escape("Reverted '" + a_path + "'")
+  svntest.actions.run_and_verify_svn(None, expected_output, [], "revert",
+                                     a_path)
+
+def revert_propdel__file(sbox):
+  "revert a simple propdel on a file"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  iota_path = os.path.join(wc_dir, 'iota')
+  svntest.main.run_svn(None, 'propset', 'foo', 'x', iota_path)
+  svntest.main.run_svn(None, 'commit', '-m', 'ps', iota_path)
+  svntest.main.run_svn(None, 'propdel', 'foo', iota_path)
+  expected_output = re.escape("Reverted '" + iota_path + "'")
+  svntest.actions.run_and_verify_svn(None, expected_output, [], "revert",
+                                     iota_path)
+
+def revert_replaced_with_history_file(sbox):
+  "revert a file that was replaced by a copied file"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  iota_path = os.path.join(wc_dir, 'iota')
+  mu_path = os.path.join(wc_dir, 'A', 'mu')
+
+  # Remember the original text of 'mu'
+  text_r1, err = svntest.actions.run_and_verify_svn(None, None, [],
+                                                    'cat', mu_path)
+  # delete mu and replace it with a copy of iota
+  svntest.main.run_svn(None, 'rm', mu_path)
+  svntest.main.run_svn(None, 'mv', iota_path, mu_path)
+
+  expected_status = svntest.actions.get_virginal_state(wc_dir, 1)
+  expected_status.tweak('A/mu', status='  ', wc_rev=2)
+  expected_status.remove('iota')
+  expected_output = svntest.wc.State(wc_dir, {
+    'iota': Item(verb='Deleting'),
+    'A/mu': Item(verb='Replacing'),
+    })
+  svntest.actions.run_and_verify_commit(wc_dir,
+                                        expected_output,
+                                        expected_status,
+                                        None, None, None, None, None,
+                                        wc_dir)
+
+  # now revert back to the state in r1
+  expected_output = svntest.wc.State(wc_dir, {
+    'A/mu': Item(status='A '),
+    'iota': Item(status='A ')
+    })
+  expected_status = svntest.actions.get_virginal_state(wc_dir, 1)
+  expected_status.tweak('A/mu', status='R ', copied='+', wc_rev='-')
+  expected_status.tweak('iota', status='A ', copied='+', wc_rev='-')
+  expected_skip = wc.State(wc_dir, { })
+  expected_disk   = svntest.main.greek_state.copy()
+  svntest.actions.run_and_verify_merge(wc_dir, '2', '1',
+                                       sbox.repo_url,
+                                       expected_output,
+                                       expected_disk,
+                                       expected_status,
+                                       expected_skip)
+
+  # and commit in r3
+  expected_status = svntest.actions.get_virginal_state(wc_dir, 1)
+  expected_status.tweak('A/mu', status='  ', wc_rev=3)
+  expected_status.tweak('iota', status='  ', wc_rev=3)
+  expected_output = svntest.wc.State(wc_dir, {
+    'iota': Item(verb='Adding'),
+    'A/mu': Item(verb='Replacing'),
+    })
+  svntest.actions.run_and_verify_commit(wc_dir,
+                                        expected_output,
+                                        expected_status,
+                                        None, None, None, None, None,
+                                        wc_dir)
+
+  # Verify the content of 'mu'
+  svntest.actions.run_and_verify_svn(None, text_r1, [], 'cat', mu_path)
+
+  # situation: no local modifications, mu has its original content again.
+
+  # revert 'mu' locally, shouldn't change a thing.
+  svntest.actions.run_and_verify_svn(None, [], [], "revert",
+                                     mu_path)
+
+  # Verify the content of 'mu'
+  svntest.actions.run_and_verify_svn(None, text_r1, [], 'cat', mu_path)
+
+
+#----------------------------------------------------------------------
+# Test for issue #2804.
+def status_of_missing_dir_after_revert(sbox):
+  "status after schedule-delete, revert, and local rm"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  A_D_G_path = os.path.join(wc_dir, "A", "D", "G")
+
+  svntest.actions.run_and_verify_svn(None, None, [], "rm", A_D_G_path)
+  expected_output = re.escape("Reverted '" + A_D_G_path + "'")
+  svntest.actions.run_and_verify_svn(None, expected_output, [], "revert",
+                                     A_D_G_path)
+
+  svntest.actions.run_and_verify_svn(None, None, [],
+                                     "status", wc_dir)
+
+  svntest.main.safe_rmtree(A_D_G_path)
+
+  output, errput = svntest.actions.run_and_verify_svn(None, None, [],
+                                                      "status", wc_dir)
+  expected_output = "!      " + A_D_G_path + "\n"
+  if expected_output not in output:
+    raise svntest.Failure("Expected output '%s'" % expected_output)
+    
+
+#----------------------------------------------------------------------
+# Test for issue #2804 with replaced directory
+def status_of_missing_dir_after_revert_replaced_with_history_dir(sbox):
+  "status after replace+, revert, and local rm"
+
+  sbox.build()
+  wc_dir = sbox.wc_dir
+  repo_url = sbox.repo_url
+
+  # delete A/D/G and commit
+  G_path = os.path.join(wc_dir, "A", "D", "G")
+  svntest.actions.run_and_verify_svn(None, None, [], "rm", G_path)
+  expected_status = svntest.actions.get_virginal_state(wc_dir, 1)
+  expected_status.remove('A/D/G', 'A/D/G/rho', 'A/D/G/pi', 'A/D/G/tau')
+  expected_output = svntest.wc.State(wc_dir, {
+    'A/D/G': Item(verb='Deleting'),
+    })
+  svntest.actions.run_and_verify_commit(wc_dir,
+                                        expected_output,
+                                        expected_status,
+                                        None, None, None, None, None,
+                                        wc_dir)
+
+  # copy A/D/G from A/B/E and commit
+  E_path = os.path.join(wc_dir, "A", "B", "E")
+  svntest.actions.run_and_verify_svn(None, None, [], "cp", E_path, G_path)
+  expected_status.add({
+    'A/D/G' : Item(status='  ', wc_rev='3'),
+    'A/D/G/alpha' : Item(status='  ', wc_rev='3'),
+    'A/D/G/beta' : Item(status='  ', wc_rev='3')
+    })
+  expected_output = svntest.wc.State(wc_dir, {
+    'A/D/G': Item(verb='Adding'),
+    })
+  svntest.actions.run_and_verify_commit(wc_dir,
+                                        expected_output,
+                                        expected_status,
+                                        None, None, None, None, None,
+                                        wc_dir)
+
+  # now rollback to r1, thereby reinstating the old 'G'
+  expected_output = svntest.wc.State(wc_dir, {
+    'A/D/G': Item(status='D '),
+    'A/D/G/alpha': Item(status='D '),
+    'A/D/G/beta': Item(status='D '),
+    'A/D/G': Item(status='A '),
+    'A/D/G/rho': Item(status='A '),
+    'A/D/G/pi': Item(status='A '),
+    'A/D/G/tau': Item(status='A '),
+    })
+  expected_status = svntest.actions.get_virginal_state(wc_dir, 1)
+  expected_status.tweak('A/D/G', status='R ', copied='+', wc_rev='-')
+  expected_status.tweak('A/D/G/rho', status='A ', copied='+', wc_rev='-')
+  expected_status.tweak('A/D/G/pi',  status='A ', copied='+', wc_rev='-')
+  expected_status.tweak('A/D/G/tau', status='A ', copied='+', wc_rev='-')
+  expected_status.add({
+    'A/D/G/alpha' : Item(status='D ', copied='+', wc_rev='-'),
+    'A/D/G/beta' : Item(status='D ', copied='+', wc_rev='-')
+    })
+  expected_skip = wc.State(wc_dir, { })
+  expected_disk   = svntest.main.greek_state.copy()
+  svntest.actions.run_and_verify_merge(wc_dir, '3', '1',
+                                       sbox.repo_url,
+                                       expected_output,
+                                       expected_disk,
+                                       expected_status,
+                                       expected_skip,
+                                       dry_run = 0)
+
+  # now test if the revert works ok
+  expected_output =\
+   ["Reverted '" + G_path + "'\n",
+    "Reverted '" + os.path.join(G_path, 'pi') + "'\n",
+    "Reverted '" + os.path.join(G_path, 'rho') + "'\n",
+    "Reverted '" + os.path.join(G_path, 'tau') + "'\n",
+    "Reverted '" + os.path.join(G_path, 'alpha') + "'\n",
+    "Reverted '" + os.path.join(G_path, 'beta') + "'\n"]
+
+  out, err = svntest.actions.run_and_verify_svn(None, None, [], "revert", "-R",
+                                                G_path)
+  for line in out:
+    if not line in expected_output:
+      raise svntest.Failure("Expected output '%s'" % expected_output)
+
+  expected_output =\
+    ["?      " + os.path.join(G_path, "pi") + "\n",
+     "?      " + os.path.join(G_path, "rho") + "\n",
+     "?      " + os.path.join(G_path, "tau") + "\n"]
+  out, err = svntest.actions.run_and_verify_svn(None, None, [],
+                                                "status", wc_dir)
+  for line in out:
+    if not line in expected_output:
+      raise svntest.Failure("Expected output '%s'" % expected_output)
+
+  svntest.main.safe_rmtree(G_path)
+
+  expected_output = ["!      " + G_path + "\n"]
+  out, err = svntest.actions.run_and_verify_svn(None, None, [], "status",
+                                                wc_dir)
+  for line in out:
+    if not line in expected_output:
+      raise svntest.Failure("Expected output '%s'" % expected_output)
+
 
 ########################################################################
 # Run the tests
@@ -600,6 +849,13 @@ test_list = [ None,
               revert_after_second_replace,
               revert_after_manual_conflict_resolution__text,
               revert_after_manual_conflict_resolution__prop,
+              revert_propset__dir,
+              revert_propset__file,
+              revert_propdel__dir,
+              revert_propdel__file,
+              status_of_missing_dir_after_revert,
+              status_of_missing_dir_after_revert_replaced_with_history_dir,
+              revert_replaced_with_history_file,
              ]
 
 if __name__ == '__main__':
