@@ -44,43 +44,43 @@ struct rep_args
 
 
 static svn_error_t *
-txn_body_write_new_rep (void *baton, trail_t *trail)
+txn_body_write_new_rep(void *baton, trail_t *trail)
 {
   struct rep_args *b = (struct rep_args *) baton;
   representation_t *rep;
-  SVN_ERR (svn_fs_base__parse_representation_skel (&rep, b->skel,
-                                                   trail->pool));
-  return svn_fs_bdb__write_new_rep (&(b->key), b->fs, rep, trail, trail->pool);
+  SVN_ERR(svn_fs_base__parse_representation_skel(&rep, b->skel,
+                                                 trail->pool));
+  return svn_fs_bdb__write_new_rep(&(b->key), b->fs, rep, trail, trail->pool);
 }
 
 
 static svn_error_t *
-txn_body_write_rep (void *baton, trail_t *trail)
+txn_body_write_rep(void *baton, trail_t *trail)
 {
   struct rep_args *b = (struct rep_args *) baton;
   representation_t *rep;
-  SVN_ERR (svn_fs_base__parse_representation_skel (&rep, b->skel,
-                                                   trail->pool));
-  return svn_fs_bdb__write_rep (b->fs, b->key, rep, trail, trail->pool);
+  SVN_ERR(svn_fs_base__parse_representation_skel(&rep, b->skel,
+                                                 trail->pool));
+  return svn_fs_bdb__write_rep(b->fs, b->key, rep, trail, trail->pool);
 }
 
 
 static svn_error_t *
-txn_body_read_rep (void *baton, trail_t *trail)
+txn_body_read_rep(void *baton, trail_t *trail)
 {
   struct rep_args *b = (struct rep_args *) baton;
   representation_t *rep;
-  SVN_ERR (svn_fs_bdb__read_rep (&rep, b->fs, b->key, trail, trail->pool));
-  return svn_fs_base__unparse_representation_skel (&(b->skel), rep,
-                                                   trail->pool);
+  SVN_ERR(svn_fs_bdb__read_rep(&rep, b->fs, b->key, trail, trail->pool));
+  return svn_fs_base__unparse_representation_skel(&(b->skel), rep,
+                                                  trail->pool);
 }
 
 
 static svn_error_t *
-txn_body_delete_rep (void *baton, trail_t *trail)
+txn_body_delete_rep(void *baton, trail_t *trail)
 {
   struct rep_args *b = (struct rep_args *) baton;
-  return svn_fs_bdb__delete_rep (b->fs, b->key, trail, trail->pool);
+  return svn_fs_bdb__delete_rep(b->fs, b->key, trail, trail->pool);
 }
 
 
@@ -88,10 +88,10 @@ txn_body_delete_rep (void *baton, trail_t *trail)
 /* Representation Table Test functions. */
 
 static svn_error_t *
-write_new_rep (const char **msg, 
-               svn_boolean_t msg_only,
-               svn_test_opts_t *opts,
-               apr_pool_t *pool)
+write_new_rep(const char **msg, 
+              svn_boolean_t msg_only,
+              svn_test_opts_t *opts,
+              apr_pool_t *pool)
 {
   struct rep_args args;
   const char *rep = "((fulltext 0 ) a83t2Z0q)";
@@ -103,32 +103,32 @@ write_new_rep (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-write-new-rep",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-write-new-rep",
+           "bdb", pool));
 
   /* Set up transaction baton */
   args.fs = fs;
-  args.skel = svn_fs_base__parse_skel (rep, strlen (rep), pool);
+  args.skel = svn_fs_base__parse_skel(rep, strlen(rep), pool);
   args.key = NULL;
 
   /* Write new rep to reps table. */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, txn_body_write_new_rep, &args,
-                                   pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, txn_body_write_new_rep, &args,
+                                 pool));
 
   if (args.key == NULL)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "error writing new representation");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "error writing new representation");
 
   return SVN_NO_ERROR;
 }
 
 
 static svn_error_t *
-write_rep (const char **msg, 
-           svn_boolean_t msg_only,
-           svn_test_opts_t *opts,
-           apr_pool_t *pool)
+write_rep(const char **msg, 
+          svn_boolean_t msg_only,
+          svn_test_opts_t *opts,
+          apr_pool_t *pool)
 {
   struct rep_args new_args;
   struct rep_args args;
@@ -142,42 +142,42 @@ write_rep (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-write-rep",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-write-rep",
+           "bdb", pool));
 
   /* Set up transaction baton */
   new_args.fs = fs;
-  new_args.skel = svn_fs_base__parse_skel (new_rep, strlen (new_rep), pool);
+  new_args.skel = svn_fs_base__parse_skel(new_rep, strlen(new_rep), pool);
   new_args.key = NULL;
 
   /* Write new rep to reps table. */
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                                   txn_body_write_new_rep, &new_args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_write_new_rep, &new_args, pool));
 
   /* Make sure we got a valid key. */
   if (new_args.key == NULL)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "error writing new representation");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "error writing new representation");
 
   /* Set up transaction baton for re-writing reps. */
   args.fs = new_args.fs;
-  args.skel = svn_fs_base__parse_skel (rep, strlen (rep), pool);
+  args.skel = svn_fs_base__parse_skel(rep, strlen(rep), pool);
   args.key = new_args.key;
 
   /* Overwrite first rep in reps table. */
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                                   txn_body_write_rep, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_write_rep, &args, pool));
 
   return SVN_NO_ERROR;
 }
 
 
 static svn_error_t *
-read_rep (const char **msg, 
-          svn_boolean_t msg_only,
-          svn_test_opts_t *opts,
-          apr_pool_t *pool)
+read_rep(const char **msg, 
+         svn_boolean_t msg_only,
+         svn_test_opts_t *opts,
+         apr_pool_t *pool)
 {
   struct rep_args new_args;
   struct rep_args args;
@@ -196,8 +196,8 @@ read_rep (const char **msg,
     (pool, "((fulltext 0  (md5 16 XXXXXXXXXXXXXXXX)) kfogel31337");
   char *new_rep_after = apr_pstrdup
     (pool, "((fulltext 0  (md5 16 XXXXXXXXXXXXXXXX)) a83t2Z0");
-  int rep_after_len = strlen (rep_after);
-  int new_rep_after_len = strlen (new_rep_after);
+  int rep_after_len = strlen(rep_after);
+  int new_rep_after_len = strlen(new_rep_after);
 
   /* Replace the fake fake checksums with the real fake checksums.
      And someday, when checksums are actually calculated, we can
@@ -220,77 +220,77 @@ read_rep (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-read-rep",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-read-rep",
+           "bdb", pool));
 
   /* Set up transaction baton */
   new_args.fs = fs;
-  new_args.skel = svn_fs_base__parse_skel (new_rep_before,
-                                           strlen (new_rep_before), pool);
+  new_args.skel = svn_fs_base__parse_skel(new_rep_before,
+                                          strlen(new_rep_before), pool);
   new_args.key = NULL;
 
   /* Write new rep to reps table. */
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                                   txn_body_write_new_rep, &new_args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_write_new_rep, &new_args, pool));
 
   /* Make sure we got a valid key. */
   if (new_args.key == NULL)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "error writing new representation");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "error writing new representation");
 
   /* Read the new rep back from the reps table. */
   read_args.fs = new_args.fs;
   read_args.skel = NULL;
   read_args.key = new_args.key;
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                                   txn_body_read_rep, &read_args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_read_rep, &read_args, pool));
 
   /* Make sure the skel matches. */
   if (! read_args.skel)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "error reading new representation");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "error reading new representation");
   
-  skel_data = svn_fs_base__unparse_skel (read_args.skel, pool);
-  if (memcmp (skel_data->data, new_rep_after, new_rep_after_len) != 0)
-    return svn_error_createf (SVN_ERR_FS_GENERAL, NULL,
-                              "representation corrupted (first check)");
+  skel_data = svn_fs_base__unparse_skel(read_args.skel, pool);
+  if (memcmp(skel_data->data, new_rep_after, new_rep_after_len) != 0)
+    return svn_error_createf(SVN_ERR_FS_GENERAL, NULL,
+                             "representation corrupted (first check)");
   
   /* Set up transaction baton for re-writing reps. */
   args.fs = new_args.fs;
-  args.skel = svn_fs_base__parse_skel (rep, strlen (rep), pool);
+  args.skel = svn_fs_base__parse_skel(rep, strlen(rep), pool);
   args.key = new_args.key;
 
   /* Overwrite first rep in reps table. */
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                              txn_body_write_rep, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_write_rep, &args, pool));
 
   /* Read the new rep back from the reps table (using the same FS and
      key as the first read...let's make sure this thing didn't get
      written to the wrong place). */
   read_args.skel = NULL;
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                                   txn_body_read_rep, &read_args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_read_rep, &read_args, pool));
 
   /* Make sure the skel matches. */
   if (! read_args.skel)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "error reading new representation");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "error reading new representation");
   
-  skel_data = svn_fs_base__unparse_skel (read_args.skel, pool);
-  if (memcmp (skel_data->data, rep_after, rep_after_len) != 0)
-    return svn_error_createf (SVN_ERR_FS_GENERAL, NULL,
-                              "representation corrupted (second check)");
+  skel_data = svn_fs_base__unparse_skel(read_args.skel, pool);
+  if (memcmp(skel_data->data, rep_after, rep_after_len) != 0)
+    return svn_error_createf(SVN_ERR_FS_GENERAL, NULL,
+                             "representation corrupted (second check)");
 
   return SVN_NO_ERROR;
 }
 
 
 static svn_error_t *
-delete_rep (const char **msg, 
-            svn_boolean_t msg_only,
-            svn_test_opts_t *opts,
-            apr_pool_t *pool)
+delete_rep(const char **msg, 
+           svn_boolean_t msg_only,
+           svn_test_opts_t *opts,
+           apr_pool_t *pool)
 {
   struct rep_args new_args;
   struct rep_args delete_args;
@@ -305,42 +305,42 @@ delete_rep (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-delete-rep",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-delete-rep",
+           "bdb", pool));
 
   /* Set up transaction baton */
   new_args.fs = fs;
-  new_args.skel = svn_fs_base__parse_skel (new_rep, strlen (new_rep), pool);
+  new_args.skel = svn_fs_base__parse_skel(new_rep, strlen(new_rep), pool);
   new_args.key = NULL;
 
   /* Write new rep to reps table. */
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                                   txn_body_write_new_rep, &new_args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_write_new_rep, &new_args, pool));
 
   /* Make sure we got a valid key. */
   if (new_args.key == NULL)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "error writing new representation");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "error writing new representation");
 
   /* Delete the rep we just wrote. */
   delete_args.fs = new_args.fs;
   delete_args.key = new_args.key;
-  SVN_ERR (svn_fs_base__retry_txn (new_args.fs, 
-                                   txn_body_delete_rep, &delete_args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(new_args.fs, 
+                                 txn_body_delete_rep, &delete_args, pool));
 
   /* Try to read the new rep back from the reps table. */
   read_args.fs = new_args.fs;
   read_args.skel = NULL;
   read_args.key = new_args.key;
-  err = svn_fs_base__retry_txn (new_args.fs, 
-                                txn_body_read_rep, &read_args, pool);
+  err = svn_fs_base__retry_txn(new_args.fs, 
+                               txn_body_read_rep, &read_args, pool);
 
   /* We better have an error... */
   if ((! err) && (read_args.skel))
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "error deleting representation");
-  svn_error_clear (err);
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "error deleting representation");
+  svn_error_clear(err);
 
   return SVN_NO_ERROR;
 }
@@ -350,11 +350,11 @@ delete_rep (const char **msg,
 /* Helper functions and batons for strings-table testing. */
 
 static svn_error_t *
-verify_expected_record (svn_fs_t *fs, 
-                        const char *key, 
-                        const char *expected_text,
-                        apr_size_t expected_len,
-                        trail_t *trail)
+verify_expected_record(svn_fs_t *fs, 
+                       const char *key, 
+                       const char *expected_text,
+                       apr_size_t expected_len,
+                       trail_t *trail)
 {
   apr_size_t size;
   char buf[100];
@@ -363,45 +363,45 @@ verify_expected_record (svn_fs_t *fs,
   svn_filesize_t string_size;
 
   /* Check the string size. */
-  SVN_ERR (svn_fs_bdb__string_size (&string_size, fs, key, 
-                                    trail, trail->pool));
+  SVN_ERR(svn_fs_bdb__string_size(&string_size, fs, key, 
+                                  trail, trail->pool));
   if (string_size > SVN_MAX_OBJECT_SIZE)
-    return svn_error_createf (SVN_ERR_FS_GENERAL, NULL,
-                              "record size is too large "
-                              "(got %" SVN_FILESIZE_T_FMT ", "
-                              "limit is %" APR_SIZE_T_FMT ")",
-                              string_size, SVN_MAX_OBJECT_SIZE);
+    return svn_error_createf(SVN_ERR_FS_GENERAL, NULL,
+                             "record size is too large "
+                             "(got %" SVN_FILESIZE_T_FMT ", "
+                             "limit is %" APR_SIZE_T_FMT ")",
+                             string_size, SVN_MAX_OBJECT_SIZE);
   size = (apr_size_t) string_size;
   if (size != expected_len)
-    return svn_error_createf (SVN_ERR_FS_GENERAL, NULL,
-                              "record has unexpected size "
-                              "(got %" APR_SIZE_T_FMT ", "
-                              "expected %" APR_SIZE_T_FMT ")",
-                              size, expected_len);
+    return svn_error_createf(SVN_ERR_FS_GENERAL, NULL,
+                             "record has unexpected size "
+                             "(got %" APR_SIZE_T_FMT ", "
+                             "expected %" APR_SIZE_T_FMT ")",
+                             size, expected_len);
 
   /* Read the string back in 100-byte chunks. */
-  text = svn_stringbuf_create ("", trail->pool);
+  text = svn_stringbuf_create("", trail->pool);
   while (1)
     {
-      size = sizeof (buf);
-      SVN_ERR (svn_fs_bdb__string_read (fs, key, buf, offset, &size, 
-                                        trail, trail->pool));
+      size = sizeof(buf);
+      SVN_ERR(svn_fs_bdb__string_read(fs, key, buf, offset, &size, 
+                                      trail, trail->pool));
       if (size == 0)
         break;
-      svn_stringbuf_appendbytes (text, buf, size);
+      svn_stringbuf_appendbytes(text, buf, size);
       offset += size;
     }
 
   /* Check the size and contents of the read data. */
   if (text->len != expected_len)
-    return svn_error_createf (SVN_ERR_FS_GENERAL, NULL,
-                              "record read returned unexpected size "
-                              "(got %" APR_SIZE_T_FMT ", "
-                              "expected %" APR_SIZE_T_FMT ")",
-                              size, expected_len);
-  if (memcmp (expected_text, text->data, expected_len))
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "record read returned unexpected data");
+    return svn_error_createf(SVN_ERR_FS_GENERAL, NULL,
+                             "record read returned unexpected size "
+                             "(got %" APR_SIZE_T_FMT ", "
+                             "expected %" APR_SIZE_T_FMT ")",
+                             size, expected_len);
+  if (memcmp(expected_text, text->data, expected_len))
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "record read returned unexpected data");
 
   return SVN_NO_ERROR;
 }
@@ -417,49 +417,49 @@ struct string_args
 
 
 static svn_error_t *
-txn_body_verify_string (void *baton, trail_t *trail)
+txn_body_verify_string(void *baton, trail_t *trail)
 {
   struct string_args *b = (struct string_args *) baton;
-  return verify_expected_record (b->fs, b->key, b->text, b->len, trail);
+  return verify_expected_record(b->fs, b->key, b->text, b->len, trail);
 }
 
 
 static svn_error_t *
-txn_body_string_append (void *baton, trail_t *trail)
+txn_body_string_append(void *baton, trail_t *trail)
 {
   struct string_args *b = (struct string_args *) baton;
-  return svn_fs_bdb__string_append (b->fs, &(b->key), b->len, 
-                                    b->text, trail, trail->pool);
+  return svn_fs_bdb__string_append(b->fs, &(b->key), b->len, 
+                                   b->text, trail, trail->pool);
 }
 
 
 static svn_error_t *
-txn_body_string_clear (void *baton, trail_t *trail)
+txn_body_string_clear(void *baton, trail_t *trail)
 {
   struct string_args *b = (struct string_args *) baton;
-  return svn_fs_bdb__string_clear (b->fs, b->key, trail, trail->pool);
+  return svn_fs_bdb__string_clear(b->fs, b->key, trail, trail->pool);
 }
 
 
 static svn_error_t *
-txn_body_string_delete (void *baton, trail_t *trail)
+txn_body_string_delete(void *baton, trail_t *trail)
 {
   struct string_args *b = (struct string_args *) baton;
-  return svn_fs_bdb__string_delete (b->fs, b->key, trail, trail->pool);
+  return svn_fs_bdb__string_delete(b->fs, b->key, trail, trail->pool);
 }
 
 
 static svn_error_t *
-txn_body_string_size (void *baton, trail_t *trail)
+txn_body_string_size(void *baton, trail_t *trail)
 {
   struct string_args *b = (struct string_args *) baton;
   svn_filesize_t string_size;
-  SVN_ERR (svn_fs_bdb__string_size (&string_size, b->fs, b->key, 
-                                    trail, trail->pool));
+  SVN_ERR(svn_fs_bdb__string_size(&string_size, b->fs, b->key, 
+                                  trail, trail->pool));
   if (string_size > SVN_MAX_OBJECT_SIZE)
     return svn_error_createf
       (SVN_ERR_FS_GENERAL, NULL,
-       "txn_body_string_size: string size is too largs "
+       "txn_body_string_size: string size is too large "
        "(got %" SVN_FILESIZE_T_FMT ", limit is %" APR_SIZE_T_FMT ")",
        string_size, SVN_MAX_OBJECT_SIZE);
   b->len = (apr_size_t) string_size;
@@ -468,21 +468,21 @@ txn_body_string_size (void *baton, trail_t *trail)
 
 
 static svn_error_t *
-txn_body_string_append_fail (void *baton, trail_t *trail)
+txn_body_string_append_fail(void *baton, trail_t *trail)
 {
   struct string_args *b = (struct string_args *) baton;
-  SVN_ERR (svn_fs_bdb__string_append (b->fs, &(b->key), b->len, 
-                                      b->text, trail, trail->pool));
-  return svn_error_create (SVN_ERR_TEST_FAILED, NULL,
-                           "la dee dah, la dee day...");
+  SVN_ERR(svn_fs_bdb__string_append(b->fs, &(b->key), b->len, 
+                                    b->text, trail, trail->pool));
+  return svn_error_create(SVN_ERR_TEST_FAILED, NULL,
+                          "la dee dah, la dee day...");
 }
 
 static svn_error_t *
-txn_body_string_copy (void *baton, trail_t *trail)
+txn_body_string_copy(void *baton, trail_t *trail)
 {
   struct string_args *b = (struct string_args *) baton;
-  return svn_fs_bdb__string_copy (b->fs, &(b->key), b->key, 
-                                  trail, trail->pool);
+  return svn_fs_bdb__string_copy(b->fs, &(b->key), b->key, 
+                                 trail, trail->pool);
 }
 
 
@@ -525,10 +525,10 @@ static const char *bigstring3 =
 
 
 static svn_error_t *
-test_strings (const char **msg, 
-              svn_boolean_t msg_only,
-              svn_test_opts_t *opts,
-              apr_pool_t *pool)
+test_strings(const char **msg, 
+             svn_boolean_t msg_only,
+             svn_test_opts_t *opts,
+             apr_pool_t *pool)
 {
   struct string_args args;
   svn_fs_t *fs;
@@ -540,9 +540,9 @@ test_strings (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-test-strings",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-test-strings",
+           "bdb", pool));
 
   /* The plan (after each step below, verify the size and contents of
      the string):
@@ -560,70 +560,70 @@ test_strings (const char **msg,
   args.fs = fs;
   args.key = NULL;
   args.text = bigstring1;
-  args.len = strlen (bigstring1);
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_append, &args, pool));
+  args.len = strlen(bigstring1);
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_append, &args, pool));
 
   /* Make sure a key was returned. */
   if (! args.key)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "write of new string failed to return new key");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "write of new string failed to return new key");
 
   /* Verify record's size and contents. */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_verify_string, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_verify_string, &args, pool));
 
   /* Append a second string to our first one. */
   args.text = bigstring2;
-  args.len = strlen (bigstring2);
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_append, &args, pool));
+  args.len = strlen(bigstring2);
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_append, &args, pool));
   
   /* Verify record's size and contents. */
-  string = svn_stringbuf_create (bigstring1, pool);
-  svn_stringbuf_appendcstr (string, bigstring2);
+  string = svn_stringbuf_create(bigstring1, pool);
+  svn_stringbuf_appendcstr(string, bigstring2);
   args.text = string->data;
   args.len = string->len;
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_verify_string, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_verify_string, &args, pool));
 
   /* Clear the record */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_clear, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_clear, &args, pool));
 
   /* Verify record's size and contents. */
   args.text = "";
   args.len = 0;
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_verify_string, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_verify_string, &args, pool));
 
   /* Append a third string to our first one. */
   args.text = bigstring3;
-  args.len = strlen (bigstring3);
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_append, &args, pool));
+  args.len = strlen(bigstring3);
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_append, &args, pool));
 
   /* Verify record's size and contents. */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_verify_string, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_verify_string, &args, pool));
 
   /* Delete our record...she's served us well. */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_delete, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_delete, &args, pool));
 
   /* Now, we expect a size request on this record to fail with
      SVN_ERR_FS_NO_SUCH_STRING. */
   {
-    svn_error_t *err = svn_fs_base__retry_txn (args.fs, txn_body_string_size,
-                                               &args, pool);
+    svn_error_t *err = svn_fs_base__retry_txn(args.fs, txn_body_string_size,
+                                              &args, pool);
 
     if (! err)
-      return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                               "query unexpectedly successful");
+      return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                              "query unexpectedly successful");
     if (err->apr_err != SVN_ERR_FS_NO_SUCH_STRING)
-      return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                               "query failed with unexpected error");
-    svn_error_clear (err);
+      return svn_error_create(SVN_ERR_FS_GENERAL, err,
+                              "query failed with unexpected error");
+    svn_error_clear(err);
   }
 
   return SVN_NO_ERROR;
@@ -631,10 +631,10 @@ test_strings (const char **msg,
 
 
 static svn_error_t *
-write_null_string (const char **msg, 
-                   svn_boolean_t msg_only,
-                   svn_test_opts_t *opts,
-                   apr_pool_t *pool)
+write_null_string(const char **msg, 
+                  svn_boolean_t msg_only,
+                  svn_test_opts_t *opts,
+                  apr_pool_t *pool)
 {
   struct string_args args;
   svn_fs_t *fs;
@@ -645,26 +645,26 @@ write_null_string (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-test-strings",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-test-strings",
+           "bdb", pool));
 
   args.fs = fs;
   args.key = NULL;
   args.text = NULL;
   args.len = 0;
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, txn_body_string_append, &args,
-                                   pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, txn_body_string_append, &args,
+                                 pool));
 
   return SVN_NO_ERROR;
 }
 
 
 static svn_error_t *
-abort_string (const char **msg, 
-              svn_boolean_t msg_only,
-              svn_test_opts_t *opts,
-              apr_pool_t *pool)
+abort_string(const char **msg, 
+             svn_boolean_t msg_only,
+             svn_test_opts_t *opts,
+             apr_pool_t *pool)
 {
   struct string_args args, args2;
   svn_fs_t *fs;
@@ -675,9 +675,9 @@ abort_string (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-abort-string",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-abort-string",
+           "bdb", pool));
 
   /* The plan:
 
@@ -690,48 +690,48 @@ abort_string (const char **msg,
   args.fs = fs;
   args.key = NULL;
   args.text = bigstring1;
-  args.len = strlen (bigstring1);
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_append, &args, pool));
+  args.len = strlen(bigstring1);
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_append, &args, pool));
 
   /* Make sure a key was returned. */
   if (! args.key)
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "write of new string failed to return new key");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "write of new string failed to return new key");
 
   /* Verify record's size and contents. */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_verify_string, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_verify_string, &args, pool));
 
   /* Append a second string to our first one. */
   args2.fs = fs;
   args2.key = args.key;
   args2.text = bigstring2;
-  args2.len = strlen (bigstring2);
+  args2.len = strlen(bigstring2);
   {
     svn_error_t *err;
 
     /* This function is *supposed* to fail with SVN_ERR_TEST_FAILED */
-    err = svn_fs_base__retry_txn (args.fs, txn_body_string_append_fail, 
-                                  &args2, pool);
+    err = svn_fs_base__retry_txn(args.fs, txn_body_string_append_fail, 
+                                 &args2, pool);
     if ((! err) || (err->apr_err != SVN_ERR_TEST_FAILED))
-      return svn_error_create (SVN_ERR_TEST_FAILED, NULL,
-                               "failed to intentionally abort a trail");
-    svn_error_clear (err);
+      return svn_error_create(SVN_ERR_TEST_FAILED, err,
+                              "failed to intentionally abort a trail");
+    svn_error_clear(err);
   }
   
   /* Verify that record's size and contents are still that of string1 */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_verify_string, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_verify_string, &args, pool));
 
   return SVN_NO_ERROR;
 }
 
 static svn_error_t *
-copy_string (const char **msg, 
-             svn_boolean_t msg_only,
-             svn_test_opts_t *opts,
-             apr_pool_t *pool)
+copy_string(const char **msg, 
+            svn_boolean_t msg_only,
+            svn_test_opts_t *opts,
+            apr_pool_t *pool)
 {
   struct string_args args;
   svn_fs_t *fs;
@@ -743,35 +743,35 @@ copy_string (const char **msg,
     return SVN_NO_ERROR;
 
   /* Create a new fs and repos */
-  SVN_ERR (svn_test__create_fs
-           (&fs, "test-repo-copy-string",
-            "bdb", pool));
+  SVN_ERR(svn_test__create_fs
+          (&fs, "test-repo-copy-string",
+           "bdb", pool));
 
   /*  Write a new string (string1). */
   args.fs = fs;
   args.key = NULL;
   args.text = bigstring1;
-  args.len = strlen (bigstring1);
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_append, &args, pool));
+  args.len = strlen(bigstring1);
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_append, &args, pool));
 
   /* Make sure a key was returned. */
   if (! (old_key = args.key))
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "write of new string failed to return new key");
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "write of new string failed to return new key");
 
   /* Now copy that string into a new location. */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_string_copy, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_string_copy, &args, pool));
 
   /* Make sure a different key was returned. */
-  if ((! args.key) || (! strcmp (old_key, args.key)))
-    return svn_error_create (SVN_ERR_FS_GENERAL, NULL,
-                             "copy of string failed to return new key");
+  if ((! args.key) || (! strcmp(old_key, args.key)))
+    return svn_error_create(SVN_ERR_FS_GENERAL, NULL,
+                            "copy of string failed to return new key");
 
   /* Verify record's size and contents. */
-  SVN_ERR (svn_fs_base__retry_txn (args.fs, 
-                                   txn_body_verify_string, &args, pool));
+  SVN_ERR(svn_fs_base__retry_txn(args.fs, 
+                                 txn_body_verify_string, &args, pool));
 
   return SVN_NO_ERROR;
 }
@@ -783,13 +783,13 @@ copy_string (const char **msg,
 struct svn_test_descriptor_t test_funcs[] =
   {
     SVN_TEST_NULL,
-    SVN_TEST_PASS (write_new_rep),
-    SVN_TEST_PASS (write_rep),
-    SVN_TEST_PASS (read_rep),
-    SVN_TEST_PASS (delete_rep),
-    SVN_TEST_PASS (test_strings),
-    SVN_TEST_PASS (write_null_string),
-    SVN_TEST_PASS (abort_string),
-    SVN_TEST_PASS (copy_string),
+    SVN_TEST_PASS(write_new_rep),
+    SVN_TEST_PASS(write_rep),
+    SVN_TEST_PASS(read_rep),
+    SVN_TEST_PASS(delete_rep),
+    SVN_TEST_PASS(test_strings),
+    SVN_TEST_PASS(write_null_string),
+    SVN_TEST_PASS(abort_string),
+    SVN_TEST_PASS(copy_string),
     SVN_TEST_NULL
   };
